inc
===

DuneConverter
-------------

.. doxygenclass:: sme::simulate::DuneConverter

Pde
---

.. doxygenclass:: sme::simulate::Pde

Simulation
----------

.. doxygenclass:: sme::simulate::Simulation

SimulationData
--------------

.. doxygenclass:: sme::simulate::SimulationData

.. doxygenstruct:: sme::simulate::AvgMinMax

SimulationOptions
-----------------

.. doxygenstruct:: sme::simulate::Options

.. doxygenenum:: sme::simulate::SimulatorType

.. doxygenstruct:: sme::simulate::PixelOptions

.. doxygenstruct:: sme::simulate::PixelIntegratorError

.. doxygenenum:: sme::simulate::PixelIntegratorType

.. doxygenstruct:: sme::simulate::DuneOptions

.. doxygenenum:: sme::simulate::DuneDiscretizationType

Optimization
------------

.. doxygenclass:: sme::simulate::Optimization

OptimizationOptions
-------------------

.. doxygenstruct:: sme::simulate::OptimizeOptions

.. doxygenstruct:: sme::simulate::OptParam

.. doxygenenum:: sme::simulate::OptParamType

.. doxygenstruct:: sme::simulate::OptCost

.. doxygenenum:: sme::simulate::OptCostType

.. doxygenenum:: sme::simulate::OptCostDiffType

.. doxygenstruct:: sme::simulate::OptAlgorithm

.. doxygenenum:: sme::simulate::OptAlgorithmType
